__all__ = ['text']
def text(txt):
    """
        - Purpose
            Create a binary image of a text.
        - Synopsis
            y = text(txt)
        - Input
            txt: String Default: "". Text to be written.
        - Output
            y: Binary image.
        - Description
            text creates the binary image y of the text txt . The
            background of y is 0, while its foreground is 1. The text should
            be composed only by lower and upper case letters.

    """
    from numpy import reshape, array

    FontDft = binary([
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   1,   0,   0,
     0,   0,   0,   1,   0,   0,   1,   0,   0,
     0,   0,   0,   1,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   1,   0,   0,   0,
     0,   0,   1,   0,   0,   1,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   1,   0,   0,   1,   0,   0,   0,
     0,   0,   1,   0,   0,   1,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   1,   0,   0,   1,   0,   0,   0,
     0,   0,   1,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   1,   0,   0,   0,   0,
     0,   1,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   1,   0,
     0,   0,   0,   0,   1,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   1,   0,   0,   1,   0,   0,
     0,   1,   0,   1,   0,   0,   1,   0,   0,
     0,   0,   1,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   1,   0,   0,
     0,   0,   1,   0,   0,   1,   0,   1,   0,
     0,   0,   1,   0,   0,   1,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   1,   0,   0,   0,
     0,   1,   0,   0,   0,   1,   0,   0,   0,
     0,   1,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   1,   1,   1,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   1,   0,   0,   0,
     0,   1,   0,   0,   0,   1,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   1,   1,   0,   0,
     0,   0,   1,   1,   1,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   1,   1,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   1,   1,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   1,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   0,   0,   0,   0,
     0,   0,   1,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   1,   1,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   1,   1,   0,   0,
     0,   0,   0,   0,   1,   0,   1,   0,   0,
     0,   0,   0,   1,   0,   0,   1,   0,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   1,   1,   1,   1,   0,   0,
     0,   1,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   1,   1,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   1,   1,   1,   1,   0,   0,
     0,   1,   1,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   1,   1,   0,
     0,   0,   1,   1,   1,   1,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   1,   1,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   1,   1,   1,   0,
     0,   1,   0,   1,   0,   0,   0,   1,   0,
     0,   1,   0,   1,   0,   0,   1,   1,   0,
     0,   1,   0,   0,   1,   1,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   1,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   1,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   1,   1,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   1,   0,   0,   0,
     0,   1,   0,   0,   1,   0,   0,   0,   0,
     0,   1,   1,   1,   0,   0,   0,   0,   0,
     0,   1,   0,   1,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   1,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   1,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   1,   0,   0,   0,   1,   1,   0,
     0,   1,   0,   1,   0,   1,   0,   1,   0,
     0,   1,   0,   1,   0,   1,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   1,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   1,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   1,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   1,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   1,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   1,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   1,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   1,   0,   1,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
    55,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   1,   1,   0,
     0,   0,   1,   1,   1,   1,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   1,   1,   1,   1,   0,   0,
     0,   1,   1,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   1,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   1,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   1,   1,   0,
     0,   0,   1,   1,   1,   1,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   1,   1,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   1,   0,
     0,   0,   0,   1,   0,   0,   0,   1,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   1,   1,   1,   1,   0,   0,
     0,   1,   1,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   1,   1,   0,   0,
     0,   1,   0,   1,   1,   0,   0,   0,   0,
     0,   1,   1,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   1,   1,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   0,   1,   1,   0,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   1,   1,   1,   1,   0,   0,
     0,   1,   1,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   1,   1,   1,   1,   0,   0,
     0,   1,   1,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   1,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   1,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   1,   1,   0,
     0,   0,   1,   1,   1,   1,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   1,   1,   1,   0,   0,
     0,   0,   1,   1,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   1,   1,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   0,   1,   0,   0,   1,   0,
     0,   1,   0,   1,   0,   1,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   1,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   0,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   1,   1,   0,   0,
     0,   0,   1,   1,   1,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   1,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   1,   1,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   1,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   1,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   1,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   1,   1,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   1,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   1,   1,   1,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   1,   1,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   1,   0,   0,   0,
     0,   0,   0,   0,   1,   1,   0,   0,   0,
     0,   0,   0,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   0,   0,   0,   1,   0,   0,   0,   0,
     0,   1,   1,   1,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0,
     0,   0,   0,   0,   0,   0,   0,   0,   0])
    FIRST_CHAR =  32
    LAST_CHAR  = 126
    N_CHARS    = LAST_CHAR - FIRST_CHAR
    WIDTH_DFT  =   9
    HEIGHT_DFT =  15
    FontDft = reshape(FontDft,(HEIGHT_DFT * N_CHARS, WIDTH_DFT))
    txt_i = array(txt,'l') - FIRST_CHAR
    for i in range(len(txt_i)):
      ind = txt_i[i]
      assert ind < (LAST_CHAR-FIRST_CHAR),'text, code not allowed'
      if i == 0:
        y = FontDft[ind*HEIGHT_DFT:(ind+1)*HEIGHT_DFT,:]
      else:
        y = concat('w',y,FontDft[ind*HEIGHT_DFT:(ind+1)*HEIGHT_DFT,:])
    return y
